@@ -9,7 +9,7 @@ require_once 'Horde/Form/Type.php';
  * other functionality for the Horde Application Framework.
  *
  * Copyright 2001-2007 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2001-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -686,7 +686,7 @@ class Horde_Form {
 
     function execute()
     {
-        Horde::logMessage('Warning: Horde_Form::execute() called, should be overridden', 'DEBUG');
+        Horde::log('Warning: Horde_Form::execute() called, should be overridden', 'DEBUG');
     }
 
     /**
@@ -719,6 +719,11 @@ class Horde_Form {
     function _getInfoFromVariables($variables, &$vars, &$info)
     {
         foreach ($variables as $var) {
+            if ($var->isDisabled()) {
+                // Disabled fields are not submitted by some browsers, so don't
+                // pretend they were.
+                continue;
+            }
             if ($var->isArrayVal()) {
                 $var->getInfo($vars, $values);
                 if (is_array($values)) {
